mysql.exceptions.server.Cant_Create_Thread

Package mysql :: Package exceptions :: Module server :: Class Cant_Create_Thread |
[hide private]
[frames] | no frames]

# Class Cant_Create_Thread

source code

    exceptions.Exception --+
                           |
                  base.Error --+
                               |
                base.MySQL_Error --+
                                   |
                                  Cant_Create_Thread

Can't create a new thread (errno %d); if you are not out of available memory, you can consult the manual for a possible OS-dependent bug

Instance Methods | [hide private]
Inherited from `base.MySQL_Error`: `__init__`, `__repr__`, `__str__` Inherited from `exceptions.Exception`: `__getitem__`

Instance Variables | [hide private]
Inherited from `base.MySQL_Error`: `errno`, `error_string`